summaryrefslogtreecommitdiff
path: root/Debian/Debhelper/Dh_Buildsystems.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Debian/Debhelper/Dh_Buildsystems.pm')
-rw-r--r--Debian/Debhelper/Dh_Buildsystems.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Debian/Debhelper/Dh_Buildsystems.pm b/Debian/Debhelper/Dh_Buildsystems.pm
index df810208..3b150bd1 100644
--- a/Debian/Debhelper/Dh_Buildsystems.pm
+++ b/Debian/Debhelper/Dh_Buildsystems.pm
@@ -88,9 +88,9 @@ sub load_all_buildsystems {
}
}
# Push debhelper built-in build systems first
for my $name (@BUILDSYSTEMS) {
- error("debhelper built-in build system '$name' could not be found/loaded")
+ error("standard debhelper build system '$name' could not be found/loaded")
if not exists $buildsystems{$name};
push @buildsystems, $buildsystems{$name};
delete $buildsystems{$name};
@@ -88,9 +88,9 @@ sub load_all_buildsystems {
}
}
- # Push debhelper built-in build systems first
+ # Push standard debhelper build systems first
for my $name (@BUILDSYSTEMS) {